==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Input/cue/translations/cue_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="40"/>
        <source>CUE Plugin</source>
        <translation>Wtyczka CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="43"/>
        <source>CUE Files</source>
        <translation>Pliki CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="93"/>
        <source>About CUE Audio Plugin</source>
        <translation>O wtyczce dźwiękowej CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="94"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Wtyczka dźwiękowa CUE dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Ustawienia wtyczki CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Ogólne opcje</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Załaduj niewłaściwy plik CUE, jeśli możliwe</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Kodowanie CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Automatyczne wykrywanie kodowania</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Domyślne kodowanie:</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.6.orig.tar.bz2: qmmp-1.1.6/src/plugins/Input/cue/translations/cue_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Wtyczka CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Pliki CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="98"/>
        <source>About CUE Audio Plugin</source>
        <translation>O wtyczce CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="99"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>O wtyczce CUE dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="100"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Ustawienia wtyczki CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Ogólne opcje</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Załaduj niewłaściwy plik CUE jeśli możliwe</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Kodowanie CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Automatyczne wykrywanie kodowania</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Domyślne kodowanie:</translation>
    </message>
</context>
</TS>
